@@ -8,6 +8,8 @@ import statistics
 import numpy
 import scipy.special
 
+from textcomplexity.utils import windows
+
 
 def confidence_interval(results):
     return 1.96 * statistics.stdev(results) / math.sqrt(len(results))
@@ -28,6 +30,10 @@ def hypergeom_pmf(k, M, n, N):
     return numpy.exp(result)
 
 
+def geom_pmf(k, p):
+    return numpy.power(1-p, k-1) * p
+
+
 def average_measure(measure, sentences):
     """Calculate the measure for every sentence and return mean and
     standard deviation.
@@ -47,3 +53,24 @@ def average_measure_and_length(measure, sentences):
     scores, lengths = zip(*results)
     lengths = list(itertools.chain.from_iterable(lengths))
     return statistics.mean(scores), statistics.stdev(scores), statistics.mean(lengths), statistics.stdev(lengths)
+
+
+def bootstrap(measure, tokens, window_size, strategy="spread", **kwargs):
+    """Calculate bootstrap for surface-based measures as explained in
+    Evert et al. (2017).
+
+    kwargs are passed to measure
+
+    Evert, Stefan, Sebastian Wankerl, Elmar Nöth (2017). Reliable
+    measures of syntactic and lexical complexity: The case of Iris
+    Murdoch. In: Proceedings of the Corpus Linguistics 2017
+    Conference, Birmingham, UK.
+    http://purl.org/stefan.evert/PUB/EvertWankerlNoeth2017.pdf
+
+    """
+    results = []
+    for window in windows.disjoint_windows(tokens, window_size, strategy):
+        results.append(measure(window, **kwargs))
+    if len(results) == 1:
+        return results[0], 0, results
+    return statistics.mean(results), confidence_interval(results), results
